#[non_exhaustive]pub enum FileStatus {
Complete {
local_size: u64,
},
Partial {
local_size: u64,
expected_size: u64,
},
Missing {
expected_size: u64,
},
}Expand description
Status of a single file in the cache.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Complete
File is fully downloaded (local size matches expected size, or no expected size known).
Partial
File exists but is smaller than expected (interrupted download),
or a .chunked.part temp file was found in the blobs directory
(repo-level heuristic — may not correspond to this specific file).
Missing
File is not present in the cache.