#[non_exhaustive]pub enum GateStatus {
Open,
Auto,
Manual,
}Expand description
Access control status of a model on the HuggingFace Hub.
Some models require users to accept license terms before downloading. The gating mode determines whether approval is automatic or manual.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Open
No gate — anyone can download without restrictions.
Auto
Automatic approval after the user accepts terms on the Hub.
Manual
Manual approval by the model author after the user requests access.
Implementations